#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FirebaseEngine_1 = require("../FirebaseEngine");
const Logger_1 = require("../utils/Logger");
const os_1 = require("os");
const path_1 = require("path");
const fs_1 = require("fs");
const randomStr_1 = require("../utils/randomStr");
/**
 * command line help table
 */
const arg = [
    {
        Name: "--to-emulators",
        "Short name": "-to",
        Description: "Copy data from project to emulators (only firestore)",
    },
    {
        Name: "--from-emulators",
        "Short name": "-from",
        Description: "Copy data from emulators to project (only firestore)",
    },
    {
        Name: "path",
        "Short name": "p",
        Description: "Path to service account JSON file",
    },
];
/**
 * command line error helper
 */
function errorHandler() {
    Logger_1.Logger.log("=========================EXAMPLES=========================");
    Logger_1.Logger.log('firebase-engine-emulators path="./test/utils/vend-park-development.json" --to-emulators');
    Logger_1.Logger.log('firebase-engine-emulators p="./test/utils/vend-park-development.json" -from');
    Logger_1.Logger.log("=========================ARGUMENTS========================");
    Logger_1.Logger.table(arg);
    Logger_1.Logger.log("===========================ERROR==========================");
}
const run = async () => {
    const settings = {};
    process.argv.forEach((val) => {
        if (val.match(/^path=/i) || val.match(/^p=/i))
            settings.path = val
                .replace(/^p=/i, "")
                .replace(/^path=/i, "")
                .replace(/"/g, "");
        if (val.match(/^--to-emulators/i) || val.match(/^-to/i)) {
            if (typeof settings.toEmulator === "boolean")
                throw new Error("Please use only one param --to-emulators (-to) or --from-emulators (-from).");
            settings.toEmulator = true;
        }
        if (val.match(/^--from-emulators/i) || val.match(/^-from/i)) {
            if (typeof settings.toEmulator === "boolean")
                throw new Error("Please use only one param --to-emulators (-to) or --from-emulators (-from).");
            settings.toEmulator = false;
        }
    });
    if (typeof settings.path !== "string")
        throw new Error("Service account path not set.");
    if (typeof settings.toEmulator !== "boolean")
        throw new Error("Param --to-emulators (-to) or --from-emulators (-from) not set.");
    const backupPath = (0, path_1.join)((0, os_1.tmpdir)(), `${(0, randomStr_1.randomStr)(8)}.backup`);
    const firebaseEngine1 = new FirebaseEngine_1.FirebaseEngine({
        path: settings.path,
        backup: backupPath,
        compress: true,
        emulators: settings.toEmulator ? false : true,
        buckets: [],
        collections: [],
    });
    await firebaseEngine1.jobs.backup.firestore();
    await firebaseEngine1.exit();
    await new Promise((res) => {
        setTimeout(res, 1);
    });
    const firebaseEngine2 = new FirebaseEngine_1.FirebaseEngine({
        path: settings.path,
        backup: backupPath,
        compress: true,
        emulators: settings.toEmulator,
        buckets: [],
        collections: [],
    });
    await firebaseEngine2.jobs.restore.firestore();
    await firebaseEngine2.exit();
    await new Promise((res) => {
        setTimeout(res, 1);
    });
    await fs_1.promises.unlink(backupPath);
};
run()
    .then(() => {
    Logger_1.Logger.log("Transfer done.");
    setTimeout(process.exit, 1, 0);
})
    .catch((error) => {
    errorHandler();
    Logger_1.Logger.error(error.message);
    setTimeout(process.exit, 1, 1);
});
//# sourceMappingURL=firebase-engine-emulators.js.map