"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobBackupAuth = void 0;
const FirebaseAuth_1 = require("../../utils/FirebaseAuth");
const template_1 = require("../../utils/template");
const AuthConverter_1 = require("../../utils/AuthConverter");
const Logger_1 = require("../../utils/Logger");
class JobBackupAuth extends template_1.JobBackupServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.auth = (0, FirebaseAuth_1.getAuth)(this.admin);
    }
    /**
     * recursive backup function
     */
    async recursiveBackup(nextPageToken) {
        const listUsers = await this.auth.listUsers(1000, nextPageToken);
        for (const userRecord of listUsers.users) {
            const docString = AuthConverter_1.AuthConverter.toString(userRecord);
            const _doc = {
                service: "auth",
                path: userRecord.uid,
                data: docString,
            };
            const self = this;
            const p = new Promise((res, rej) => {
                self.stringiferStream.write(_doc, undefined, (err) => {
                    if (err)
                        Logger_1.Logger.warn(err);
                    res();
                });
            });
            await p;
            ++this.counter;
            if (this.counter % 1000 === 0)
                Logger_1.Logger.log(" -- Auth Backuped - " +
                    this.counter +
                    " users in " +
                    this.getWorkTime() +
                    ".");
        }
        if (listUsers.pageToken)
            await this.recursiveBackup(listUsers.pageToken);
        return;
    }
    /**
     * job runner
     */
    async run() {
        this.startTimestamp = Date.now();
        let _write;
        if (this.writer.gzipStream) {
            _write = this.writer.gzipStream;
        }
        else {
            _write = this.writer.fileStream;
        }
        const unpipe = new Promise((res, rej) => {
            _write.once("unpipe", () => {
                res();
            });
        });
        this.stringiferStream.pipe(_write);
        await this.recursiveBackup();
        this.stringiferStream.unpipe(_write);
        await unpipe;
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        if (this.counter % 1000 !== 0)
            Logger_1.Logger.log(" -- Auth Backuped - " +
                this.counter +
                " users in " +
                this.getWorkTime() +
                ".");
        Logger_1.Logger.log(" - Auth Backup Complete!");
        return;
    }
}
exports.JobBackupAuth = JobBackupAuth;
//# sourceMappingURL=auth.js.map