"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobBackupFirestore = void 0;
const FirebaseFirestore_1 = require("../../utils/FirebaseFirestore");
const template_1 = require("../../utils/template");
const FirestoreConverter_1 = require("../../utils/FirestoreConverter");
const Logger_1 = require("../../utils/Logger");
class JobBackupFirestore extends template_1.JobBackupServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.firestore = (0, FirebaseFirestore_1.getFirestore)(this.admin);
        if (this.settings.emulators)
            this.firestore.settings({
                host: "localhost:8080",
                ssl: false,
            });
    }
    /**
     * backup one document function
     */
    async documentBackup(docSnap) {
        const docData = docSnap.data();
        if (!docData)
            return;
        const docString = FirestoreConverter_1.FirestoreConverter.toString(docData);
        const _doc = {
            service: "firestore",
            path: docSnap.ref.path,
            data: docString,
        };
        const self = this;
        const p = new Promise((res, rej) => {
            self.stringiferStream.write(_doc, undefined, (err) => {
                if (err)
                    Logger_1.Logger.warn(err);
                res();
            });
        });
        await p;
        ++this.counter;
        if (this.counter % 500 === 0)
            Logger_1.Logger.log(" -- Firestore Backuped - " +
                this.counter +
                " docs in " +
                this.getWorkTime() +
                ".");
        return;
    }
    /**
     * recursive backup function
     */
    async recursiveBackup(ref) {
        const collections = await ref.listCollections();
        for (const collectionRef of collections)
            if (this.settings.collections.length === 0 ||
                this.settings.collections.find((selectedCollection) => {
                    const shortName = collectionRef.path
                        .split("/")
                        .filter((parentPath, i) => i % 2 === 0)
                        .join(".");
                    return (shortName.indexOf(selectedCollection) === 0 ||
                        selectedCollection.indexOf(shortName) === 0);
                })) {
                let denied = true;
                if (this.settings.collections.length !== 0) {
                    const arr = collectionRef.path.split("/");
                    let str = "";
                    for (let i = 0; i < arr.length; i++)
                        if (i % 2 === 0) {
                            str += arr[i];
                            if (this.settings.collections.indexOf(str) !== -1) {
                                denied = false;
                                break;
                            }
                            str += ".";
                        }
                }
                else
                    denied = false;
                const collectionSnap = await collectionRef.get();
                for (let i = 1; i <= collectionSnap.docs.length; i++) {
                    if (!denied)
                        await this.documentBackup(collectionSnap.docs[i - 1]);
                    await this.recursiveBackup(collectionSnap.docs[i - 1].ref);
                }
            }
        return;
    }
    /**
     * job runner
     */
    async run() {
        this.startTimestamp = Date.now();
        let _write;
        if (this.writer.gzipStream) {
            _write = this.writer.gzipStream;
        }
        else {
            _write = this.writer.fileStream;
        }
        const unpipe = new Promise((res, rej) => {
            _write.once("unpipe", () => {
                res();
            });
        });
        this.stringiferStream.pipe(_write);
        await this.recursiveBackup(this.firestore);
        this.stringiferStream.unpipe(_write);
        await unpipe;
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        if (this.counter % 500 !== 0)
            Logger_1.Logger.log(" -- Firestore Backuped - " +
                this.counter +
                " docs in " +
                this.getWorkTime() +
                ".");
        Logger_1.Logger.log(" - Firestore Backup Complete!");
        return;
    }
}
exports.JobBackupFirestore = JobBackupFirestore;
//# sourceMappingURL=firestore.js.map