"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobBackupStorage = void 0;
const template_1 = require("../../utils/template");
const StorageConverter_1 = require("../../utils/StorageConverter");
const Logger_1 = require("../../utils/Logger");
class JobBackupStorage extends template_1.JobBackupServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
    }
    /**
     * backup one file function
     */
    async backupFile(bucket, file) {
        const bName = bucket.name.replace(new RegExp(this.settings.serviceAccount.project_id, "g"), "{default}");
        const [buffer] = await file.download();
        if (!buffer)
            return;
        const docString = StorageConverter_1.StorageConverter.toString(buffer);
        const _doc = {
            service: "storage",
            path: bName + "://" + file.name,
            data: docString,
        };
        const self = this;
        const p = new Promise((res, rej) => {
            self.stringiferStream.write(_doc, undefined, (err) => {
                if (err)
                    Logger_1.Logger.warn(err);
                res();
            });
        });
        await p;
        ++this.counter;
        if (this.counter % 100 === 0)
            Logger_1.Logger.log(" -- Storage Backuped - " +
                this.counter +
                " files in " +
                this.getWorkTime() +
                ".");
        return;
    }
    /**
     * job runner
     */
    async run() {
        const [buckets] = await this.store.getBuckets();
        this.startTimestamp = Date.now();
        let _write;
        if (this.writer.gzipStream) {
            _write = this.writer.gzipStream;
        }
        else {
            _write = this.writer.fileStream;
        }
        const unpipe = new Promise((res, rej) => {
            _write.once("unpipe", () => {
                res();
            });
        });
        this.stringiferStream.pipe(_write);
        for (const bucket of buckets)
            if (this.settings.buckets.length === 0 ||
                this.settings.buckets.indexOf(bucket.name) !== -1) {
                const [files] = await bucket.getFiles();
                if (Array.isArray(files))
                    for (const file of files)
                        await this.backupFile(bucket, file);
            }
        this.stringiferStream.unpipe(_write);
        await unpipe;
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        if (this.counter % 100 !== 0)
            Logger_1.Logger.log(" -- Storage Backuped - " +
                this.counter +
                " files in " +
                this.getWorkTime() +
                ".");
        Logger_1.Logger.log(" - Storage Backup Complete!");
        return;
    }
}
exports.JobBackupStorage = JobBackupStorage;
//# sourceMappingURL=storage.js.map