"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobCleanAuth = void 0;
const FirebaseAuth_1 = require("../../utils/FirebaseAuth");
const template_1 = require("../../utils/template");
const Logger_1 = require("../../utils/Logger");
class JobCleanAuth extends template_1.JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.auth = (0, FirebaseAuth_1.getAuth)(this.admin);
    }
    /**
     * recursive clean function
     */
    async recursiveClean(nextPageToken) {
        const listUsers = await this.auth.listUsers(1000, nextPageToken);
        const result = await this.auth.deleteUsers(listUsers.users.map((user) => {
            return user.uid;
        }));
        this.counter += result.successCount;
        Logger_1.Logger.log(" -- Auth Cleaned - " +
            this.counter +
            " users in " +
            this.getWorkTime() +
            ".");
        if (listUsers.pageToken)
            await this.recursiveClean(listUsers.pageToken);
        return;
    }
    /**
     * job runner
     */
    async run() {
        this.startTimestamp = Date.now();
        await this.recursiveClean();
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        Logger_1.Logger.log(" - Auth Clean Complete!");
        return;
    }
}
exports.JobCleanAuth = JobCleanAuth;
//# sourceMappingURL=auth.js.map