"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobCleanFirestore = void 0;
const FirebaseFirestore_1 = require("../../utils/FirebaseFirestore");
const template_1 = require("../../utils/template");
const Logger_1 = require("../../utils/Logger");
class JobCleanFirestore extends template_1.JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.firestore = (0, FirebaseFirestore_1.getFirestore)(this.admin);
        if (this.settings.emulators)
            this.firestore.settings({
                host: "localhost:8080",
                ssl: false,
            });
        this.batch = this.firestore.batch();
    }
    /**
     * commit batch and recreate
     */
    async batchClean(arr) {
        for (const ref of arr) {
            let denied = true;
            if (this.settings.collections.length !== 0) {
                const _arr = ref.path.split("/");
                let str = "";
                for (let i = 0; i < _arr.length; i++)
                    if (i % 2 === 0) {
                        str += _arr[i];
                        if (this.settings.collections.indexOf(str) !== -1) {
                            denied = false;
                            break;
                        }
                        str += ".";
                    }
            }
            else
                denied = false;
            if (!denied)
                this.batch.delete(ref);
            await this.recursiveClean(ref);
        }
        const result = await this.batch.commit();
        this.counter += result.length;
        this.batch = this.firestore.batch();
        Logger_1.Logger.log(" -- Firestore Cleaned - " +
            this.counter +
            " docs in " +
            this.getWorkTime() +
            ".");
        return;
    }
    /**
     * recursive clean function
     */
    async recursiveClean(ref) {
        const collections = await ref.listCollections();
        for (const collectionRef of collections)
            if (this.settings.collections.length === 0 ||
                this.settings.collections.find((selectedCollection) => {
                    const shortName = collectionRef.path
                        .split("/")
                        .filter((parentPath, i) => i % 2 === 0)
                        .join(".");
                    return (shortName.indexOf(selectedCollection) === 0 ||
                        selectedCollection.indexOf(shortName) === 0);
                })) {
                const collectionSnap = await collectionRef.get();
                let arr = [];
                for (let i = 1; i <= collectionSnap.docs.length; i++) {
                    arr.push(collectionSnap.docs[i - 1].ref);
                    if (i % JobCleanFirestore.batchSize === 0 ||
                        i === collectionSnap.docs.length) {
                        await this.batchClean(arr);
                        arr = [];
                    }
                }
            }
        return;
    }
    /**
     * job runner
     */
    async run() {
        this.startTimestamp = Date.now();
        await this.recursiveClean(this.firestore);
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        Logger_1.Logger.log(" - Firestore Clean Complete!");
        return;
    }
}
exports.JobCleanFirestore = JobCleanFirestore;
/**
 * document on one batch
 */
JobCleanFirestore.batchSize = 500;
//# sourceMappingURL=firestore.js.map