"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobRestoreFirestore = void 0;
const FirebaseFirestore_1 = require("../../utils/FirebaseFirestore");
const template_1 = require("../../utils/template");
const stream_1 = require("stream");
const FirestoreConverter_1 = require("../../utils/FirestoreConverter");
const Logger_1 = require("../../utils/Logger");
class JobRestoreFirestore extends template_1.JobBackupServiceRestoreTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        const self = this;
        this.writeStream = new stream_1.Writable({
            write(object, encoding, callback) {
                (async () => {
                    if (object.service !== "firestore" ||
                        typeof object.path !== "string" ||
                        typeof object.data !== "string")
                        return;
                    if (self.settings.collections.length !== 0) {
                        const arr = object.path.split("/");
                        let str = "";
                        let denied = true;
                        for (let i = 0; i < arr.length; i++)
                            if (i % 2 === 0) {
                                str += arr[i];
                                if (self.settings.collections.indexOf(str) !== -1) {
                                    denied = false;
                                    break;
                                }
                                str += ".";
                            }
                        if (denied)
                            return;
                    }
                    const docRef = self.firestore.doc(object.path);
                    const docData = FirestoreConverter_1.FirestoreConverter.fromString(object.data);
                    await self.writeBuffer.set(docRef, docData);
                    return;
                })()
                    .then(() => {
                    callback();
                    return;
                })
                    .catch((err) => {
                    callback(err);
                    return;
                });
            },
            objectMode: true,
        });
        this.writeStream.on("error", (err) => {
            Logger_1.Logger.warn(err);
        });
        this.firestore = (0, FirebaseFirestore_1.getFirestore)(this.admin);
        if (this.settings.emulators)
            this.firestore.settings({
                host: "localhost:8080",
                ssl: false,
            });
        this.writeBuffer = {
            batchSize: 500,
            iteration: 0,
            batch: self.firestore.batch(),
            clear: async () => {
                self.writeBuffer.batch = self.firestore.batch();
                return self.writeBuffer;
            },
            commit: async () => {
                const result = await self.writeBuffer.batch.commit();
                self.counter += result.length;
                await self.writeBuffer.clear();
                Logger_1.Logger.log(" -- Firebase Restored - " +
                    self.counter +
                    " docs in " +
                    self.getWorkTime() +
                    ".");
                return self.writeBuffer;
            },
            set: async (ref, data) => {
                self.writeBuffer.batch.set(ref, data);
                ++self.writeBuffer.iteration;
                if (self.writeBuffer.iteration % self.writeBuffer.batchSize === 0) {
                    await self.writeBuffer.commit();
                }
                return self.writeBuffer;
            },
        };
    }
    /**
     * job runner
     */
    async run() {
        this.startTimestamp = Date.now();
        const self = this;
        const p = new Promise((res, rej) => {
            if (self.gunzipStream) {
                const gunzip = self.gunzipStream;
                self.gunzipStream.on("unpipe", () => {
                    gunzip.unpipe(self.parserStream);
                    gunzip.close();
                    self.parserStream.end();
                });
                self.fileStream
                    .pipe(gunzip)
                    .pipe(self.parserStream)
                    .pipe(self.writeStream);
            }
            else {
                self.fileStream.pipe(self.parserStream).pipe(self.writeStream);
            }
            self.writeStream.on("finish", () => {
                res();
            });
        });
        await p;
        if (this.writeBuffer.iteration % this.writeBuffer.batchSize !== 0)
            await this.writeBuffer.commit();
        await new Promise((res) => {
            setTimeout(res, 1);
        });
        Logger_1.Logger.log(" - Firestore Restore Complete!");
        return;
    }
}
exports.JobRestoreFirestore = JobRestoreFirestore;
//# sourceMappingURL=firestore.js.map