"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FirestoreConverter = void 0;
const FirebaseFirestore_1 = require("./FirebaseFirestore");
/**
 * Firestore Document converter
 */
class FirestoreConverter {
    /**
     * Convert an object to a string
     * @param d - Object for convert
     */
    static toString(d) {
        const _obj = FirestoreConverter.toObject(d);
        return JSON.stringify(_obj);
    }
    /**
     * Internal deserialization
     * @param d - Object for deserialization
     */
    static toObject(d) {
        if (typeof d === "string")
            return { data: d, type: "string" };
        if (typeof d === "number")
            return { data: d, type: "number" };
        if (typeof d === "boolean")
            return { data: d, type: "boolean" };
        if (d === null)
            return { data: d, type: "null" };
        if (d instanceof Buffer)
            return { data: d.toString("base64"), type: "binary" };
        if (d instanceof FirebaseFirestore_1.Timestamp)
            return {
                data: { sec: d.seconds, nano: d.nanoseconds },
                type: "timestamp",
            };
        if (d instanceof FirebaseFirestore_1.DocumentReference)
            return { data: d.path, type: "document" };
        if (d instanceof FirebaseFirestore_1.GeoPoint)
            return { data: { lat: d.latitude, long: d.longitude }, type: "geopoint" };
        if (Array.isArray(d)) {
            const _arr = { data: [], type: "array" };
            for (const val of d)
                _arr.data.push(FirestoreConverter.toObject(val));
            return _arr;
        }
        const clearObject = {};
        if (d.__proto__ === clearObject.__proto__) {
            const _obj = { data: {}, type: "map" };
            for (const key in d)
                _obj.data[key] = FirestoreConverter.toObject(d[key]);
            return _obj;
        }
        throw new Error("Invalid data type.");
    }
    /**
     * Convert string to object
     * @param d - String to convert
     */
    static fromString(d) {
        const _obj = JSON.parse(d);
        return FirestoreConverter.fromObject(_obj);
    }
    /**
     * Internal serialization
     * @param d - Object for serialization
     */
    static fromObject(d) {
        const _arr = [];
        const _obj = {};
        switch (d.type) {
            case "string":
            case "number":
            case "boolean":
                return d.data;
            case "null":
                return null;
            case "binary":
                return Buffer.from(d.data, "base64");
            case "timestamp":
                return new FirebaseFirestore_1.Timestamp(d.data.sec, d.data.nano);
            case "document":
                return (0, FirebaseFirestore_1.getFirestore)().doc(d.data);
            case "geopoint":
                return new FirebaseFirestore_1.GeoPoint(d.data.lat, d.data.long);
            case "array":
                for (const val of d.data)
                    _arr.push(FirestoreConverter.fromObject(val));
                return _arr;
            case "map":
                for (const key in d.data)
                    _obj[key] = FirestoreConverter.fromObject(d.data[key]);
                return _obj;
            default:
                throw new Error("Invalid data type.");
        }
    }
}
exports.FirestoreConverter = FirestoreConverter;
//# sourceMappingURL=FirestoreConverter.js.map