/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { WriteStream } from "fs";
import { App } from "./FirebaseAdmin";
import { HashAlgorithmType } from "./FirebaseAuth";
import { Gzip } from "zlib";
import { Storage } from "@google-cloud/storage";
/**
 * write streams
 */
export declare const writers: {
    [key: string]: Writer;
};
/**
 * Create write stream
 *
 * @param path - path to file for write
 */
export declare const createWriteFileStream: (path: string, compress: boolean) => Writer;
/**
 * Writer Class for create write streams
 */
export declare class Writer {
    /**
     *
     * @param path - path to file for write
     */
    constructor(path: string, compress: boolean);
    /**
     * use compress
     */
    compress: boolean;
    /**
     * file write stream after gzipped
     */
    fileStream: WriteStream;
    /**
     * gzip stream
     */
    gzipStream?: Gzip;
}
/**
 * settings object from command line interface
 */
export interface ParsedSettings {
    /**
     * array of operations
     */
    operations: ("backup" | "clean" | "restore")[];
    /**
     * path to Firebase service account key (json)
     */
    path?: string;
    /**
     * path to backup file
     */
    backup?: string;
    /**
     * service for backup/clean/restore
     */
    services: ("firestore" | "auth" | "storage")[];
    /**
     * use compress
     */
    compress: boolean;
    /**
     * use emulators
     */
    emulators: boolean;
    /**
     * password hash config
     */
    hash_config: {
        algorithm?: HashAlgorithmType;
        base64_signer_key?: Buffer;
        base64_salt_separator?: Buffer;
        rounds?: number;
        mem_cost?: number;
    };
    /**
     * buckets for processing
     */
    buckets: string[];
    /**
     * collections for processing
     */
    collections: string[];
}
/**
 * settings object before initialization
 */
export interface SettingsBeforeInitialization {
    /**
     * path to Firebase service account key (json)
     */
    path?: string;
    /**
     * path to backup file
     */
    backup?: string;
    /**
     * use compress
     */
    compress?: boolean;
    /**
     * use emulators
     */
    emulators?: boolean;
    /**
     * password hash config
     */
    hash_config?: {
        algorithm?: HashAlgorithmType;
        base64_signer_key?: Buffer;
        base64_salt_separator?: Buffer;
        rounds?: number;
        mem_cost?: number;
    };
    /**
     * buckets for processing
     */
    buckets?: string[];
    /**
     * collections for processing
     */
    collections?: string[];
}
/**
 * settings object after initialization
 */
export interface Settings {
    /**
     * path to Firebase service account key (json)
     */
    path: string;
    /**
     * path to backup file
     */
    backup: string;
    /**
     * Firebase service account key (object)
     */
    serviceAccount: {
        [key: string]: any;
    };
    /**
     * use compress
     */
    compress: boolean;
    /**
     * use emulators
     */
    emulators: boolean;
    /**
     * password hash config
     */
    hash_config?: {
        algorithm: HashAlgorithmType;
        key: Buffer;
        saltSeparator: Buffer;
        rounds: number;
        memoryCost: number;
    };
    /**
     * buckets for processing
     */
    buckets: string[];
    /**
     * collections for processing
     */
    collections: string[];
}
/**
 * Command Line Parser
 */
export declare const cmdParser: (arg: string[]) => ParsedSettings;
/**
 * App initialization
 *
 * @param settings - settings object
 */
export declare const initialization: (settings?: SettingsBeforeInitialization) => {
    settings: Settings;
    admin: App;
    store: Storage;
};
