/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { App } from "./FirebaseAdmin";
import { Transform } from "stream";
import { ReadStream } from "fs";
import { Gunzip } from "zlib";
import { Settings, Writer } from "./initialization";
import { Storage } from "@google-cloud/storage";
/**
 * Job Template Class
 */
export declare class JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings: Settings, admin: App, store: Storage);
    /**
     * settings object
     */
    settings: Settings;
    /**
     * firebase app
     */
    admin: App;
    /**
     * Google cloud storage app
     */
    store: Storage;
}
/**
 * Job One Template Class
 */
export declare class JobOneTemplate extends JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings: Settings, admin: App, store: Storage);
    /**
     * Jobs for Firebase.Firestore
     */
    firestore(): Promise<void>;
    /**
     * Jobs for Firebase.Auth
     */
    auth(): Promise<void>;
    /**
     * Jobs for Firebase.Storage
     */
    storage(): Promise<void>;
}
/**
 * Job class
 */
export declare class JobOneServiceTemplate extends JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings: Settings, admin: App, store: Storage);
    /**
     * operation counter
     */
    counter: number;
    /**
     * get work time
     */
    getWorkTime(): string;
    /**
     * start timestamp
     */
    startTimestamp: number;
    /**
     * Job runner
     */
    run(): Promise<void>;
}
/**
 * Job backup
 */
export declare class JobBackupServiceTemplate extends JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings: Settings, admin: App, store: Storage);
    /**
     * Writer streams in object
     */
    writer: Writer;
    /**
     * object to string stream
     */
    stringiferStream: Transform;
}
/**
 * Job restore
 */
export declare class JobBackupServiceRestoreTemplate extends JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings: Settings, admin: App, store: Storage);
    /**
     * file read stream
     */
    fileStream: ReadStream;
    /**
     * unzip stream
     */
    gunzipStream?: Gunzip;
    /**
     * string to object stream
     */
    parserStream: Transform;
}
/**
 * Data Model
 */
export interface DataModel {
    /**
     * service type
     */
    service: "firestore" | "auth" | "storage";
    /**
     * document path
     */
    path: string;
    /**
     * document data
     */
    data: string;
}
