"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobBackupServiceRestoreTemplate = exports.JobBackupServiceTemplate = exports.JobOneServiceTemplate = exports.JobOneTemplate = exports.JobTemplate = void 0;
const objectstream_1 = require("@sergdudko/objectstream");
const fs_1 = require("fs");
const zlib_1 = require("zlib");
const initialization_1 = require("./initialization");
const Logger_1 = require("./Logger");
/**
 * Job Template Class
 */
class JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        this.settings = settings;
        this.admin = admin;
        this.store = store;
    }
}
exports.JobTemplate = JobTemplate;
/**
 * Job One Template Class
 */
class JobOneTemplate extends JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
    }
    /**
     * Jobs for Firebase.Firestore
     */
    async firestore() {
        Logger_1.Logger.warn("Not supported.");
        return;
    }
    /**
     * Jobs for Firebase.Auth
     */
    async auth() {
        Logger_1.Logger.warn("Not supported.");
        return;
    }
    /**
     * Jobs for Firebase.Storage
     */
    async storage() {
        Logger_1.Logger.warn("Not supported.");
        return;
    }
}
exports.JobOneTemplate = JobOneTemplate;
/**
 * Job class
 */
class JobOneServiceTemplate extends JobTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        /**
         * operation counter
         */
        this.counter = 0;
        this.startTimestamp = Date.now();
    }
    /**
     * get work time
     */
    getWorkTime() {
        const time = Date.now() - this.startTimestamp;
        if (time < 5000)
            return time + " ms";
        if (time < 300000)
            return Number.parseInt((time / 1000).toFixed()) + " sec";
        return Number.parseInt((time / 60000).toFixed()) + " min";
    }
    /**
     * Job runner
     */
    async run() {
        Logger_1.Logger.warn("Not supported.");
        return;
    }
}
exports.JobOneServiceTemplate = JobOneServiceTemplate;
/**
 * Job backup
 */
class JobBackupServiceTemplate extends JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.writer = (0, initialization_1.createWriteFileStream)(this.settings.backup, this.settings.compress);
        this.stringiferStream = new objectstream_1.Stringifer();
        this.stringiferStream.on("error", (err) => {
            Logger_1.Logger.warn(err);
        });
    }
}
exports.JobBackupServiceTemplate = JobBackupServiceTemplate;
/**
 * Job restore
 */
class JobBackupServiceRestoreTemplate extends JobOneServiceTemplate {
    /**
     * @param settings - settings object
     * @param admin - firebase app
     * @param store - google cloud storage app
     */
    constructor(settings, admin, store) {
        super(settings, admin, store);
        this.fileStream = (0, fs_1.createReadStream)(this.settings.backup, {
            flags: "r",
            mode: 0o600,
        });
        this.parserStream = new objectstream_1.Parser();
        this.fileStream.on("error", (err) => {
            Logger_1.Logger.warn(err);
        });
        this.parserStream.on("error", (err) => {
            Logger_1.Logger.warn(err);
        });
        if (this.settings.compress) {
            this.gunzipStream = (0, zlib_1.createGunzip)();
            this.gunzipStream.on("error", (err) => {
                Logger_1.Logger.warn(err);
            });
        }
    }
}
exports.JobBackupServiceRestoreTemplate = JobBackupServiceRestoreTemplate;
//# sourceMappingURL=template.js.map